@@ -1,8 +1,8 @@
 use strict;
 use warnings;
-package HTML::MasonX::Free::Component;
+package HTML::MasonX::Free::Component 0.007;
 # ABSTRACT: a component with a "main" method, not just a bunch of text
-$HTML::MasonX::Free::Component::VERSION = '0.006';
+
 use parent 'HTML::Mason::Component::FileBased';
 
 #pod =head1 OVERVIEW
@@ -60,7 +60,7 @@ HTML::MasonX::Free::Component - a component with a "main" method, not just a bun
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 OVERVIEW
 
@@ -87,13 +87,23 @@ You can pass a C<default_method_to_call> argument to the constructor for this
 class, but it's not all that easy to get where you need it, so maybe you should
 stick with the default: C<main>
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo Signes.
+This software is copyright (c) 2022 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
