@@ -1,7 +1,7 @@
 use strict;
 use warnings;
-package HTML::MasonX::Free::Request;
-$HTML::MasonX::Free::Request::VERSION = '0.006';
+package HTML::MasonX::Free::Request 0.007;
+
 # ABSTRACT: a request class that eliminates the wrapping chain
 use parent 'HTML::Mason::Request';
 
@@ -178,7 +178,7 @@ HTML::MasonX::Free::Request - a request class that eliminates the wrapping chain
 
 =head1 VERSION
 
-version 0.006
+version 0.007
 
 =head1 OVERVIEW
 
@@ -189,13 +189,23 @@ If you want a little more information:  this gets rid of the notion of
 automatically execing the whole wrapping chain (like autohandlers) for
 components.  It's gross, but it can make things a fair bit simpler.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Ricardo Signes.
+This software is copyright (c) 2022 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
